==> graphql-language-service-parser-1.9.1.jar: META-INF/resources/webjars/graphql-language-service-parser/1.9.1/CHANGELOG.md <==
# graphql-language-service-parser

## 1.9.1

### Patch Changes

- [`6869ce77`](https://github.com/graphql/graphiql/commit/6869ce7767050787db5f1017abf82fa5a52fc97a) [#1816](https://github.com/graphql/graphiql/pull/1816) Thanks [@acao](https://github.com/acao)! - improve peer resolutions for graphql 14 & 15. `14.5.0` minimum is for built-in typescript types, and another method only available in `14.4.0`

## [1.9.0](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.8.0...graphql-language-service-parser@1.9.0) (2021-01-07)

### Features

- implied or external fragments, for [#612](https://github.com/graphql/graphiql/issues/612) ([#1750](https://github.com/graphql/graphiql/issues/1750)) ([cfed265](https://github.com/graphql/graphiql/commit/cfed265e3cf31875b39ea517781a217fcdfcadc2))

## [1.8.0](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.7.0...graphql-language-service-parser@1.8.0) (2021-01-03)

### Features

- merge completion logic (for implements &, variables) ([#1747](https://github.com/graphql/graphiql/issues/1747)) ([0ac0a85](https://github.com/graphql/graphiql/commit/0ac0a856cfc715d7885a9965a9a9114ef2ca4b1a))

## [1.7.0](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.5...graphql-language-service-parser@1.7.0) (2020-12-28)

### Features

- interfaces implementing interfaces for the LSP ([#1742](https://github.com/graphql/graphiql/issues/1742)) ([c4cba85](https://github.com/graphql/graphiql/commit/c4cba85e869105f5363ebcb3826b4cf7b7e62c00))

## [1.6.5](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.4...graphql-language-service-parser@1.6.5) (2020-11-28)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.4](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.3...graphql-language-service-parser@1.6.4) (2020-09-18)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.3](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.2...graphql-language-service-parser@1.6.3) (2020-09-11)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.2](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.1...graphql-language-service-parser@1.6.2) (2020-08-12)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.1](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0...graphql-language-service-parser@1.6.1) (2020-08-06)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.0](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0-alpha.6...graphql-language-service-parser@1.6.0) (2020-06-11)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.0-alpha.6](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0-alpha.5...graphql-language-service-parser@1.6.0-alpha.6) (2020-06-04)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.0-alpha.5](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0-alpha.4...graphql-language-service-parser@1.6.0-alpha.5) (2020-06-04)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.0-alpha.4](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0-alpha.3...graphql-language-service-parser@1.6.0-alpha.4) (2020-05-17)

### Bug Fixes

- remove problematic file resolution module from webpack sco… ([#1489](https://github.com/graphql/graphiql/issues/1489)) ([8dab038](https://github.com/graphql/graphiql/commit/8dab0385772f443f73b559e2c668080733168236))

### Features

- Monaco Mode - Phase 2 - Mode & Worker ([#1459](https://github.com/graphql/graphiql/issues/1459)) ([bc95fb4](https://github.com/graphql/graphiql/commit/bc95fb46459a4437ff9471ff43c98e1c5c50f51e))
- monaco-graphql docs, api, improvements ([#1521](https://github.com/graphql/graphiql/issues/1521)) ([c79158c](https://github.com/graphql/graphiql/commit/c79158c72e976ab286e7ec3fded7f3e2d24e50d0))
- new graphql-languageservice package ([#1485](https://github.com/graphql/graphiql/issues/1485)) ([6bb3ddd](https://github.com/graphql/graphiql/commit/6bb3dddf1f97db4bc193bb7fd9de1ada8d8c8ef9))

## [1.6.0-alpha.3](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0-alpha.2...graphql-language-service-parser@1.6.0-alpha.3) (2020-04-06)

### Features

- upgrade to graphql@15.0.0 for [#1191](https://github.com/graphql/graphiql/issues/1191) ([#1204](https://github.com/graphql/graphiql/issues/1204)) ([f13c8e9](https://github.com/graphql/graphiql/commit/f13c8e9d0e66df4b051b332c7d02f4bb83e07ffd))

## [1.6.0-alpha.2](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0-alpha.1...graphql-language-service-parser@1.6.0-alpha.2) (2020-04-03)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.0-alpha.1](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0-alpha.0...graphql-language-service-parser@1.6.0-alpha.1) (2020-03-20)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.0-alpha.0](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.5.3-alpha.0...graphql-language-service-parser@1.6.0-alpha.0) (2020-03-20)

### Features

- use new GraphQL Config ([#1342](https://github.com/graphql/graphiql/issues/1342)) ([e45838f](https://github.com/graphql/graphiql/commit/e45838f5ba579e05b20f1a147ce431478ffad9aa))

## [1.5.3-alpha.1](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.5.2...graphql-language-service-parser@1.5.3-alpha.1) (2020-01-18)

### Bug Fixes

- exclusion for nonbreakable whitespace chars ([#1091](https://github.com/graphql/graphiql/issues/1091)) ([91763dd](https://github.com/graphql/graphiql/commit/91763dd)), closes [graphql/graphql-language-service#220](https://github.com/graphql/graphql-language-service/issues/220)
- linting issues, trailingCommas: all ([#1099](https://github.com/graphql/graphiql/issues/1099)) ([de4005b](https://github.com/graphql/graphiql/commit/de4005b))

## [1.5.2](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.5.1...graphql-language-service-parser@1.5.2) (2019-12-09)

### Bug Fixes

- test output, webpack resolution, clean build ([3b1c2c1](https://github.com/graphql/graphiql/commit/3b1c2c1))
- **gls-utils:** [#1055](https://github.com/graphql/graphiql/issues/1055) - move file test, refactor for fixtures ([19d8d7f](https://github.com/graphql/graphiql/commit/19d8d7f))

## [1.5.1](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.5.0...graphql-language-service-parser@1.5.1) (2019-12-03)

**Note:** Version bump only for package graphql-language-service-parser

# 1.5.0 (2019-10-04)

### Features

- convert LSP from flow to typescript ([#957](https://github.com/graphql/graphiql/issues/957)) [@acao](https://github.com/acao) @Neitch [@benjie](https://github.com/benjie) ([36ed669](https://github.com/graphql/graphiql/commit/36ed669))

## 0.0.1 (2017-03-29)

# 1.4.0 (2019-10-04)

### Features

- convert LSP from flow to typescript ([#957](https://github.com/graphql/graphiql/issues/957)) [@acao](https://github.com/acao) @Neitch [@benjie](https://github.com/benjie) ([36ed669](https://github.com/graphql/graphiql/commit/36ed669))

## 0.0.1 (2017-03-29)

# 1.4.0-alpha.0 (2019-10-04)

### Features

- convert LSP from flow to typescript ([#957](https://github.com/graphql/graphiql/issues/957)) [@acao](https://github.com/acao) @Neitch [@benjie](https://github.com/benjie) ([36ed669](https://github.com/graphql/graphiql/commit/36ed669))

## 0.0.1 (2017-03-29)

## 1.3.1-alpha.1 (2019-09-01)

## 0.0.1 (2017-03-29)

**Note:** Version bump only for package graphql-language-service-parser

## 1.3.1-alpha.0 (2019-09-01)

## 0.0.1 (2017-03-29)

**Note:** Version bump only for package graphql-language-service-parser

## 1.3.1 (2019-09-01)

## 0.0.1 (2017-03-29)

**Note:** Version bump only for package graphql-language-service-parser

==> graphql-language-service-parser-1.9.2.jar: META-INF/resources/webjars/graphql-language-service-parser/1.9.2/CHANGELOG.md <==
# graphql-language-service-parser

## 1.9.2

### Patch Changes

- [`5b8a057d`](https://github.com/graphql/graphiql/commit/5b8a057dd64ebecc391be32176a2403bb9d9ff92) [#1838](https://github.com/graphql/graphiql/pull/1838) Thanks [@acao](https://github.com/acao)! - Set all cross-runtime build targets to es6

## 1.9.1

### Patch Changes

- [`6869ce77`](https://github.com/graphql/graphiql/commit/6869ce7767050787db5f1017abf82fa5a52fc97a) [#1816](https://github.com/graphql/graphiql/pull/1816) Thanks [@acao](https://github.com/acao)! - improve peer resolutions for graphql 14 & 15. `14.5.0` minimum is for built-in typescript types, and another method only available in `14.4.0`

## [1.9.0](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.8.0...graphql-language-service-parser@1.9.0) (2021-01-07)

### Features

- implied or external fragments, for [#612](https://github.com/graphql/graphiql/issues/612) ([#1750](https://github.com/graphql/graphiql/issues/1750)) ([cfed265](https://github.com/graphql/graphiql/commit/cfed265e3cf31875b39ea517781a217fcdfcadc2))

## [1.8.0](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.7.0...graphql-language-service-parser@1.8.0) (2021-01-03)

### Features

- merge completion logic (for implements &, variables) ([#1747](https://github.com/graphql/graphiql/issues/1747)) ([0ac0a85](https://github.com/graphql/graphiql/commit/0ac0a856cfc715d7885a9965a9a9114ef2ca4b1a))

## [1.7.0](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.5...graphql-language-service-parser@1.7.0) (2020-12-28)

### Features

- interfaces implementing interfaces for the LSP ([#1742](https://github.com/graphql/graphiql/issues/1742)) ([c4cba85](https://github.com/graphql/graphiql/commit/c4cba85e869105f5363ebcb3826b4cf7b7e62c00))

## [1.6.5](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.4...graphql-language-service-parser@1.6.5) (2020-11-28)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.4](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.3...graphql-language-service-parser@1.6.4) (2020-09-18)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.3](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.2...graphql-language-service-parser@1.6.3) (2020-09-11)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.2](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.1...graphql-language-service-parser@1.6.2) (2020-08-12)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.1](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0...graphql-language-service-parser@1.6.1) (2020-08-06)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.0](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0-alpha.6...graphql-language-service-parser@1.6.0) (2020-06-11)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.0-alpha.6](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0-alpha.5...graphql-language-service-parser@1.6.0-alpha.6) (2020-06-04)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.0-alpha.5](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0-alpha.4...graphql-language-service-parser@1.6.0-alpha.5) (2020-06-04)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.0-alpha.4](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0-alpha.3...graphql-language-service-parser@1.6.0-alpha.4) (2020-05-17)

### Bug Fixes

- remove problematic file resolution module from webpack sco… ([#1489](https://github.com/graphql/graphiql/issues/1489)) ([8dab038](https://github.com/graphql/graphiql/commit/8dab0385772f443f73b559e2c668080733168236))

### Features

- Monaco Mode - Phase 2 - Mode & Worker ([#1459](https://github.com/graphql/graphiql/issues/1459)) ([bc95fb4](https://github.com/graphql/graphiql/commit/bc95fb46459a4437ff9471ff43c98e1c5c50f51e))
- monaco-graphql docs, api, improvements ([#1521](https://github.com/graphql/graphiql/issues/1521)) ([c79158c](https://github.com/graphql/graphiql/commit/c79158c72e976ab286e7ec3fded7f3e2d24e50d0))
- new graphql-languageservice package ([#1485](https://github.com/graphql/graphiql/issues/1485)) ([6bb3ddd](https://github.com/graphql/graphiql/commit/6bb3dddf1f97db4bc193bb7fd9de1ada8d8c8ef9))

## [1.6.0-alpha.3](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0-alpha.2...graphql-language-service-parser@1.6.0-alpha.3) (2020-04-06)

### Features

- upgrade to graphql@15.0.0 for [#1191](https://github.com/graphql/graphiql/issues/1191) ([#1204](https://github.com/graphql/graphiql/issues/1204)) ([f13c8e9](https://github.com/graphql/graphiql/commit/f13c8e9d0e66df4b051b332c7d02f4bb83e07ffd))

## [1.6.0-alpha.2](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0-alpha.1...graphql-language-service-parser@1.6.0-alpha.2) (2020-04-03)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.0-alpha.1](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.6.0-alpha.0...graphql-language-service-parser@1.6.0-alpha.1) (2020-03-20)

**Note:** Version bump only for package graphql-language-service-parser

## [1.6.0-alpha.0](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.5.3-alpha.0...graphql-language-service-parser@1.6.0-alpha.0) (2020-03-20)

### Features

- use new GraphQL Config ([#1342](https://github.com/graphql/graphiql/issues/1342)) ([e45838f](https://github.com/graphql/graphiql/commit/e45838f5ba579e05b20f1a147ce431478ffad9aa))

## [1.5.3-alpha.1](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.5.2...graphql-language-service-parser@1.5.3-alpha.1) (2020-01-18)

### Bug Fixes

- exclusion for nonbreakable whitespace chars ([#1091](https://github.com/graphql/graphiql/issues/1091)) ([91763dd](https://github.com/graphql/graphiql/commit/91763dd)), closes [graphql/graphql-language-service#220](https://github.com/graphql/graphql-language-service/issues/220)
- linting issues, trailingCommas: all ([#1099](https://github.com/graphql/graphiql/issues/1099)) ([de4005b](https://github.com/graphql/graphiql/commit/de4005b))

## [1.5.2](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.5.1...graphql-language-service-parser@1.5.2) (2019-12-09)

### Bug Fixes

- test output, webpack resolution, clean build ([3b1c2c1](https://github.com/graphql/graphiql/commit/3b1c2c1))
- **gls-utils:** [#1055](https://github.com/graphql/graphiql/issues/1055) - move file test, refactor for fixtures ([19d8d7f](https://github.com/graphql/graphiql/commit/19d8d7f))

## [1.5.1](https://github.com/graphql/graphiql/compare/graphql-language-service-parser@1.5.0...graphql-language-service-parser@1.5.1) (2019-12-03)

**Note:** Version bump only for package graphql-language-service-parser

# 1.5.0 (2019-10-04)

### Features

- convert LSP from flow to typescript ([#957](https://github.com/graphql/graphiql/issues/957)) [@acao](https://github.com/acao) @Neitch [@benjie](https://github.com/benjie) ([36ed669](https://github.com/graphql/graphiql/commit/36ed669))

## 0.0.1 (2017-03-29)

# 1.4.0 (2019-10-04)

### Features

- convert LSP from flow to typescript ([#957](https://github.com/graphql/graphiql/issues/957)) [@acao](https://github.com/acao) @Neitch [@benjie](https://github.com/benjie) ([36ed669](https://github.com/graphql/graphiql/commit/36ed669))

## 0.0.1 (2017-03-29)

# 1.4.0-alpha.0 (2019-10-04)

### Features

- convert LSP from flow to typescript ([#957](https://github.com/graphql/graphiql/issues/957)) [@acao](https://github.com/acao) @Neitch [@benjie](https://github.com/benjie) ([36ed669](https://github.com/graphql/graphiql/commit/36ed669))

## 0.0.1 (2017-03-29)

## 1.3.1-alpha.1 (2019-09-01)

## 0.0.1 (2017-03-29)

**Note:** Version bump only for package graphql-language-service-parser

## 1.3.1-alpha.0 (2019-09-01)

## 0.0.1 (2017-03-29)

**Note:** Version bump only for package graphql-language-service-parser

## 1.3.1 (2019-09-01)

## 0.0.1 (2017-03-29)

**Note:** Version bump only for package graphql-language-service-parser
